<?php

/* This class launches the framework. */
class Framework {

	/* Constructor method for the Framework class. */
	function __construct() {
		global $framework;

		/* Set up an empty class for the global $framework object. */
		$framework = new stdClass;

		/* Load admin files. */
		add_action( 'wp_loaded', array( &$this, 'admin' ) );

		/* Define theme constants. */
		add_action( 'after_setup_theme', array( &$this, 'constants' ) );

		/* Load theme extensions. */
		add_action( 'after_setup_theme', array( &$this, 'extensions' ), 14 );

		/* Initialize the theme's default filters. */
		add_action( 'after_setup_theme', array( &$this, 'filters' ) );

		/* Load theme functions. */
		add_action( 'after_setup_theme', array( &$this, 'functions' ) );

		/* Language functions and translations setup. */
		add_action( 'after_setup_theme', array( &$this, 'i18n' ) );

		/* Handle theme supported features. */
		add_action( 'after_setup_theme', array( &$this, 'theme_support' ), 12 );

	}

	/* Define theme constants. */
	function constants() {

		/* Sets the path to the parent theme directory. */
		define( 'THEME_DIR', get_template_directory() );

		/* Sets the path to the parent theme directory URI. */
		define( 'THEME_URI', get_template_directory_uri() );

		/* Sets the path to the core framework directory. */
		define( 'FRAMEWORK_DIR', trailingslashit( THEME_DIR ) . basename( dirname( __FILE__ ) ) );

		/* Sets the path to the core framework directory URI. */
		define( 'FRAMEWORK_URI', trailingslashit( THEME_URI ) . basename( dirname( __FILE__ ) ) );

		/* Sets the path to the core framework admin directory. */
		define( 'FRAMEWORK_ADMIN', trailingslashit( FRAMEWORK_DIR ) . 'admin' );

		/* Sets the path to the core framework classes directory. */
		define( 'FRAMEWORK_CLASSES', trailingslashit( FRAMEWORK_DIR ) . 'classes' );

		/* Sets the path to the core framework extensions directory. */
		define( 'FRAMEWORK_EXTENSIONS', trailingslashit( FRAMEWORK_DIR ) . 'extensions' );

		/* Sets the path to the core framework functions directory. */
		define( 'FRAMEWORK_FUNCTIONS', trailingslashit( FRAMEWORK_DIR ) . 'functions' );

		/* Sets the path to the core framework images directory URI. */
		define( 'FRAMEWORK_IMAGES', trailingslashit( FRAMEWORK_URI ) . 'images' );

		/* Sets the path to the core framework CSS directory URI. */
		define( 'FRAMEWORK_CSS', trailingslashit( FRAMEWORK_URI ) . 'css' );

		/* Sets the path to the core framework JavaScript directory URI. */
		define( 'FRAMEWORK_JS', trailingslashit( FRAMEWORK_URI ) . 'js' );
	
	}

	/* Load admin files. */
	function admin() {
		if ( is_admin() ) {

			/* Load the post template meta box. */
			require_once( trailingslashit( FRAMEWORK_ADMIN ) . 'meta-box.php' );

			/* Load the main admin file. */
			require_once( trailingslashit( FRAMEWORK_ADMIN ) . 'theme-admin.php' );

		}
	}

	/* Load theme extensions. */
	function extensions() {

		/* Load the cleaner caption extension. */
		require_if_theme_supports( 'cleaner-caption', trailingslashit( FRAMEWORK_EXTENSIONS ) . 'cleaner-caption.php' );

		/* Load the cleaner gallery extension. */
		require_if_theme_supports( 'cleaner-gallery', trailingslashit( FRAMEWORK_EXTENSIONS ) . 'cleaner-gallery.php' );

		/* Load the entry views extension. */
		require_if_theme_supports( 'entry-views', trailingslashit( FRAMEWORK_EXTENSIONS ) . 'entry-views.php' );

		/* Load the loop pagination extension. */
		require_if_theme_supports( 'loop-pagination', trailingslashit( FRAMEWORK_EXTENSIONS ) . 'loop-pagination.php' );

		/* Load the theme layouts extension. */
		require_if_theme_supports( 'theme-layouts', trailingslashit( FRAMEWORK_EXTENSIONS ) . 'theme-layouts.php' );

	}

	/* Adds the default framework actions and filters. */
	function filters() {

		/* Remove bbPress theme compatibility if current theme supports bbPress. */
		if ( current_theme_supports( 'bbpress' ) )
			remove_action( 'bbp_init', 'bbp_setup_theme_compat', 8 );

		/* Move the WordPress generator to a better priority. */
		remove_action( 'wp_head', 'wp_generator' );
		add_action( 'wp_head', 'wp_generator', 1 );

		/* Make text widgets and term descriptions shortcode aware. */
		add_filter( 'widget_text', 'do_shortcode' );
		add_filter( 'term_description', 'do_shortcode' );

	}

	/* Load theme functions. */
	function functions() {

		/* Load the comments functions. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'comments.php' );

		/* Load the context-based functions. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'context.php' );

		/* Load the core framework functions. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'core.php' );

		/* Load media-related functions. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'media.php' );

		/* Load the menus functions. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'menus.php' );

		/* Load the post formats. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'post-formats.php' );

		/* Load the shortcodes. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'shortcodes.php' );

		/* Load the sidebars. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'sidebars.php' );

		/* Load the widgets. */
		require_once( trailingslashit( FRAMEWORK_FUNCTIONS ) . 'widgets.php' );

	}

	/* Loads theme translation files. Files are expected to be prefixed with the template or stylesheet path (example: 'templatename-en_US.mo'). */
	function i18n() {
		global $framework;

		/* Get the user's locale. */
		$locale = get_locale();

		/* Locate a locale-specific functions file. */
		$locale_functions = locate_template( array( "languages/{$locale}.php", "{$locale}.php" ) );

		/* If the locale file exists and is readable, load it. */
		if ( !empty( $locale_functions ) && is_readable( $locale_functions ) )
			require_once( $locale_functions );
 
	}

	/* Removes theme supported features from themes in the case that a user has a plugin installed that handles the functionality. */
	function theme_support() {

		/* Remove support for the breadcrumb trail extension if the plugin is installed. */
		if ( function_exists( 'breadcrumb_trail' ) )
			remove_theme_support( 'breadcrumb-trail' );

		/* Remove support for the cleaner caption extension if the plugin is installed. */
		if ( function_exists( 'cleaner_caption' ) )
			remove_theme_support( 'cleaner-caption' );

		/* Remove support for the cleaner gallery extension if the plugin is installed. */
		if ( function_exists( 'cleaner_gallery' ) )
			remove_theme_support( 'cleaner-gallery' );

		/* Remove support for the entry views extension if the plugin is installed. */
		if ( function_exists( 'entry_views_post_type_support' ) )
			remove_theme_support( 'entry-views' );

		/* Remove support for the loop pagination extension if the plugin is installed. */
		if ( function_exists( 'loop_pagination' ) )
			remove_theme_support( 'loop-pagination' );

	}

}

?>